from setuptools import setup
d = 'A simple python package to generate short code via predefined code and size , also you can add extra strings .'
l_d = '''
This is a beta project . 
So don't be mean . This is a simple short code generator like !@asd for my Django project . 
I just uploaded for you guys so just go easy on this project . 
It has no dependency and uses built in modules like random and string .
'''
setup(name='pyshort',
      version='1.0',
      description=d,
      long_description=l_d,
      url='https://github.com/nishowsan/pyshort/',
      author='Adib Mohsin',
      author_email='md.nishow@gmail.com',
      license='MIT',
      packages=['pyshort'],
      zip_safe=False)



import random
import string

lower_str = string.ascii_lowercase
upper_str = string.ascii_uppercase
digits = string.digits
code_gen = lower_str + upper_str + digits


def short(code=code_gen, size=4, extra_string=None):
    if extra_string is not None:
        code += extra_string
    return ''.join(random.choice(code) for _ in range(size))
